==> rocsparse-5.6.1-1-x86_64.pkg.tar.zst: opt/rocm/include/rocsparse/rocsparse-version.h <==
/* ************************************************************************
 * Copyright (C) 2018-2022 Advanced Micro Devices, Inc. All rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 * ************************************************************************ */

/*!\file
 * \brief rocsparse-version.h provides the configured version and settings
 */

#ifndef _ROCSPARSE_VERSION_H_
#define _ROCSPARSE_VERSION_H_

/* clang-format off */
#define ROCSPARSE_VERSION_MAJOR     2
#define ROCSPARSE_VERSION_MINOR     5
#define ROCSPARSE_VERSION_PATCH     2
#define ROCSPARSE_VERSION_TWEAK     
/* clang-format on */

#endif /* _ROCSPARSE_VERSION_H_ */

==> rocsparse-6.2.4-1.1-x86_64.pkg.tar.zst: opt/rocm/include/rocsparse/rocsparse-version.h <==
/* ************************************************************************
 * Copyright (C) 2018-2023 Advanced Micro Devices, Inc. All rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 * ************************************************************************ */

/*!\file
 * \brief rocsparse-version.h provides the configured version and settings
 */

#ifndef ROCSPARSE_VERSION_H
#define ROCSPARSE_VERSION_H

/* clang-format off */
#define ROCSPARSE_VERSION_MAJOR     3
#define ROCSPARSE_VERSION_MINOR     2
#define ROCSPARSE_VERSION_PATCH     1
#define ROCSPARSE_VERSION_TWEAK     
/* clang-format on */

#endif /* ROCSPARSE_VERSION_H */
